@@ -6,7 +6,7 @@ from manakit_mantine.base import (
     MantineProvider,
     MemoizedMantineProvider,
 )
-from manakit_mantine.inputs import form_input
+from manakit_mantine.inputs import text_input
 from manakit_mantine.date import date_input
 from manakit_mantine.number_input import number_input
 from manakit_mantine.masked_input import masked_input
@@ -28,8 +28,9 @@ from manakit_mantine.nav_link import nav_link
 from manakit_mantine.number_formatter import number_formatter
 from manakit_mantine.table import table
 from manakit_mantine.scroll_area import scroll_area
+from manakit_mantine.scroll_area_with_controls import scroll_area_with_controls
 from manakit_mantine.tags_input import tags_input
-
+from manakit_mantine.rich_select import rich_select
 
 __all__ = [
     "MANTINE_LIBARY",
@@ -43,7 +44,6 @@ __all__ = [
     "autocomplete",
     "button",
     "date_input",
-    "form_input",
     "input",
     "json_input",
     "masked_input",
@@ -53,10 +53,13 @@ __all__ = [
     "number_formatter",
     "number_input",
     "password_input",
+    "rich_select",
     "rich_text_editor",
     "scroll_area",
+    "scroll_area_with_controls",
     "select",
     "table",
     "tags_input",
+    "text_input",
     "textarea",
 ]
